/// <reference types="react" />
import { EditorState, Extension, EditorStateConfig } from '@codemirror/state';
import { EditorView, ViewUpdate } from '@codemirror/view';
export interface ReactCodeMirrorProps extends Omit<EditorStateConfig, 'doc' | 'extensions'>, Omit<React.HTMLAttributes<HTMLDivElement>, 'onChange' | 'placeholder'> {
    /** value of the auto created model in the editor. */
    value?: string;
    height?: string;
    minHeight?: string;
    maxHeight?: string;
    width?: string;
    minWidth?: string;
    maxWidth?: string;
    autoFocus?: boolean;
    placeholder?: string | HTMLElement;
    theme?: 'light' | 'dark' | 'none' | Extension;
    basicSetup?: boolean | any;
    /**
     * This disables editing of the editor content by the user.
     * @default true
     */
    editable?: boolean;
    /**
     * This disables editing of the editor content by the user.
     * @default false
     */
    readOnly?: boolean;
    /**
     * Controls whether pressing the `Tab` key inserts a tab character and indents the text (`true`)
     * or behaves according to the browser's default behavior (`false`).
     * @default true
     */
    indentWithTab?: boolean;
    /** Fired whenever a change occurs to the document. */
    onChange?(value: string, viewUpdate: ViewUpdate): void;
    /** Some data on the statistics editor. */
    onCreateEditor?(view: EditorView, state: EditorState): void;
    extensions?: Extension[];
    root?: ShadowRoot | Document;
}
export interface ReactCodeMirrorRef {
    editor?: HTMLDivElement | null;
    state?: EditorState;
    view?: EditorView;
}
export interface UseCodeMirror extends ReactCodeMirrorProps {
    container?: HTMLDivElement | null;
}
export declare function useCodeMirror(props: UseCodeMirror): {
    state: EditorState | undefined;
    setState: import("react").Dispatch<import("react").SetStateAction<EditorState | undefined>>;
    view: EditorView | undefined;
    setView: import("react").Dispatch<import("react").SetStateAction<EditorView | undefined>>;
    container: HTMLDivElement | null | undefined;
    setContainer: import("react").Dispatch<import("react").SetStateAction<HTMLDivElement | null | undefined>>;
};
//# sourceMappingURL=hooks.d.ts.map